@@ -1,7 +1,7 @@
 from typing import Any, Dict, Iterable, List, Optional, Set, Tuple, Type, Union
 
 from antlr4.ParserRuleContext import ParserRuleContext
-from triad.utils.assertion import assert_or_throw
+from triad import assert_or_throw
 
 from _qpd_antlr import QPDParser as qp
 from _qpd_antlr import QPDVisitor
@@ -986,7 +986,7 @@ class SelectVisitor(ExpressionVisitor):
         self.assert_none(ctx.identifierList())
         alias = ""
         if ctx.errorCapturingIdentifier() is not None:
-            alias = self.to_str(ctx.errorCapturingIdentifier(), "")
+            alias = self.to_str(ctx.errorCapturingIdentifier(), "", unquote=True)
         for col in self.visit(ctx.expression()):
             yield col if alias == "" else col.rename(alias)
 
