@@ -516,37 +516,77 @@ class QPDPandasEngine(QPDEngine):
         return ndf[keys]
 
 
-class _RowsIndexer(BaseIndexer):
-    def __init__(self, start: Optional[int], end: Optional[int], **kwargs: Any):
-        window = 0 if start is None or end is None else end - start + 1
-        kw = dict(kwargs)
-        kw["window_size"] = window
-        kw["start"] = start
-        kw["end"] = end
+if pd.__version__ <= "1.4.4":  # noqa: C901
 
-        super().__init__(**kw)
+    class _RowsIndexer(BaseIndexer):
+        def __init__(self, start: Optional[int], end: Optional[int], **kwargs: Any):
+            window = 0 if start is None or end is None else end - start + 1
+            kw = dict(kwargs)
+            kw["window_size"] = window
+            kw["start"] = start
+            kw["end"] = end
 
-    def get_window_bounds(
-        self,
-        num_values: int = 0,
-        min_periods: Optional[int] = None,
-        center: Optional[bool] = None,
-        closed: Optional[str] = None,
-    ) -> Tuple[np.ndarray, np.ndarray]:
-        if self.start is None:
-            start = np.zeros(num_values, dtype=np.int64)
-        else:
-            start = np.arange(self.start, self.start + num_values, dtype=np.int64)
-            if self.start < 0:
-                start[: -self.start] = 0
-            elif self.start > 0:
-                start[-self.start :] = num_values
-        if self.end is None:
-            end = np.full(num_values, num_values, dtype=np.int64)
-        else:
-            end = np.arange(self.end + 1, self.end + 1 + num_values, dtype=np.int64)
-            if self.end > 0:
-                end[-self.end :] = num_values
-            elif self.end < 0:
-                end[: -self.end] = 0
-        return start, end
+            super().__init__(**kw)
+
+        def get_window_bounds(
+            self,
+            num_values: int = 0,
+            min_periods: Optional[int] = None,
+            center: Optional[bool] = None,
+            closed: Optional[str] = None,
+        ) -> Tuple[np.ndarray, np.ndarray]:
+            if self.start is None:
+                start = np.zeros(num_values, dtype=np.int64)
+            else:
+                start = np.arange(self.start, self.start + num_values, dtype=np.int64)
+                if self.start < 0:
+                    start[: -self.start] = 0
+                elif self.start > 0:
+                    start[-self.start :] = num_values
+            if self.end is None:
+                end = np.full(num_values, num_values, dtype=np.int64)
+            else:
+                end = np.arange(self.end + 1, self.end + 1 + num_values, dtype=np.int64)
+                if self.end > 0:
+                    end[-self.end :] = num_values
+                elif self.end < 0:
+                    end[: -self.end] = 0
+            return start, end
+
+else:
+
+    class _RowsIndexer(BaseIndexer):  # type: ignore
+        def __init__(self, start: Optional[int], end: Optional[int], **kwargs: Any):
+            window = 0 if start is None or end is None else end - start + 1
+            kw = dict(kwargs)
+            kw["window_size"] = window
+            kw["start"] = start
+            kw["end"] = end
+
+            super().__init__(**kw)
+
+        def get_window_bounds(
+            self,
+            num_values: int = 0,
+            min_periods: Optional[int] = None,
+            center: Optional[bool] = None,
+            closed: Optional[str] = None,
+            step: Optional[int] = None,
+        ) -> Tuple[np.ndarray, np.ndarray]:
+            if self.start is None:
+                start = np.zeros(num_values, dtype=np.int64)
+            else:
+                start = np.arange(self.start, self.start + num_values, dtype=np.int64)
+                if self.start < 0:
+                    start[: -self.start] = 0
+                elif self.start > 0:
+                    start[-self.start :] = num_values
+            if self.end is None:
+                end = np.full(num_values, num_values, dtype=np.int64)
+            else:
+                end = np.arange(self.end + 1, self.end + 1 + num_values, dtype=np.int64)
+                if self.end > 0:
+                    end[-self.end :] = num_values
+                elif self.end < 0:
+                    end[: -self.end] = 0
+            return start, end
