@@ -14,6 +14,22 @@ class SQLTests(object):
             self.eq_sqlite("SELECT *, 1 AS x, 2.5 AS y, 'z' AS z FROM a AS x", a=df)
             self.eq_sqlite("SELECT *, -(1.0+a)/3 AS x, +(2.5) AS y FROM a AS x", a=df)
 
+        def test_basic_select_from_special_chars(self):
+            df = self.make_rand_df(
+                5, **{"a b": (int, 2), "-": (str, 3), "c": (float, 4)}
+            )
+            self.eq_sqlite("SELECT 1 AS `a c`, 1.5 AS `-`, 'x' AS c")
+            self.eq_sqlite("SELECT 1+2 AS `a b`, 1.5*3 AS b, 'x' AS c")
+            self.eq_sqlite("SELECT *, 1 AS `c d` FROM a", a=df)
+            self.eq_sqlite("SELECT * FROM a AS x", a=df)
+            self.eq_sqlite(
+                "SELECT `-` AS `b b `, `a b`+1-2*3.0/4 AS `cc`, x.* FROM a AS x", a=df
+            )
+            self.eq_sqlite("SELECT *, 1 AS x, 2.5 AS y, 'z' AS z FROM a AS x", a=df)
+            self.eq_sqlite(
+                "SELECT *, -(1.0+`a b`)/3 AS x, +(2.5) AS y FROM a AS x", a=df
+            )
+
         def test_case_when(self):
             a = self.make_rand_df(100, a=(int, 20), b=(str, 30), c=(float, 40))
             self.eq_sqlite(
@@ -126,6 +142,20 @@ class SQLTests(object):
                 b=b,
             )
 
+        def test_join_inner_special_chars(self):
+            a = self.make_rand_df(
+                100, **{"a b": (int, 40), "b": (str, 40), "c": (float, 40)}
+            )
+            b = self.make_rand_df(
+                80, **{"d": (float, 10), "a b": (int, 10), "b": (str, 10)}
+            )
+            self.eq_sqlite(
+                "SELECT a.*, d, d*c AS x FROM a "
+                "INNER JOIN b ON a.`a b`=b.`a b` AND a.b=b.b",
+                a=a,
+                b=b,
+            )
+
         def test_join_left(self):
             a = self.make_rand_df(100, a=(int, 40), b=(str, 40), c=(float, 40))
             b = self.make_rand_df(80, d=(float, 10), a=(int, 10), b=(str, 10))
