@@ -55,7 +55,7 @@ class TestsBase(TestCase):
             elif dt is bool:
                 s = np.where(np.random.randint(2, size=size), True, False)
             elif dt is float:
-                s = np.random.rand(size)
+                s = np.random.rand(size)  # type: ignore
             elif dt is str:
                 r = [f"ssssss{x}" for x in range(10)]
                 c = np.random.randint(10, size=size)
