@@ -103,6 +103,15 @@ def test_pre_scan():
         dict(c=c), "SELECT SUM(a), ROW_NUMBER() OVER(PARTITION BY b ORDER BY c) FROM c"
     )
 
+    # special chars
+    a = pd.DataFrame([[0, 1], [0, 2], [1, 3]], columns=["a b", "-"])
+    assert_eq(dict(a=a), "SELECT a.* FROM a", "a.a b,a.-")
+    assert_eq(dict(a=a), "SELECT `a b`, `-` FROM a", "a.a b,a.-")
+
+    a = pd.DataFrame([[0, 1], [0, 2], [1, 3]], columns=["", " "])
+    assert_eq(dict(a=a), "SELECT a.* FROM a", "a.,a. ")
+    assert_eq(dict(a=a), "SELECT ` `, `` FROM a", "a. ,a.")
+
 
 def test_pre_scan_join():
     def assert_eq(dfs, sql, *joins):
@@ -1024,11 +1033,7 @@ def _debug_run(sql, rule, visitor, **kwargs):
     sql = QPDSql(sql, rule)
     ctx = QPDWorkflowContext(QPDPandasEngine(), kwargs)
     wf = QPDWorkflow(ctx)
-    v = visitor(
-        VisitorContext(
-            sql=sql, workflow=wf, dfs=wf.dfs
-        )
-    )
+    v = visitor(VisitorContext(sql=sql, workflow=wf, dfs=wf.dfs))
     wf.assemble_output(v.visit(sql.tree))
     wf.run()
     return ctx.result, v
